@@ -7,6 +7,7 @@
 #include "name.h"
 #include "lz4.h"
 #include <cmath>
+#include <memory>
 
 namespace ots {
 
@@ -48,17 +49,17 @@ bool OpenTypeSILF::Parse(const uint8_t* data, size_t length,
                               OTS_MAX_DECOMPRESSED_TABLE_SIZE / (1024.0 * 1024.0),
                               decompressed_size / (1024.0 * 1024.0));
         }
-        std::vector<uint8_t> decompressed(decompressed_size);
+        std::unique_ptr<uint8_t> decompressed(new uint8_t[decompressed_size]());
         int ret = LZ4_decompress_safe_partial(
             reinterpret_cast<const char*>(data + table.offset()),
-            reinterpret_cast<char*>(decompressed.data()),
+            reinterpret_cast<char*>(decompressed.get()),
             table.remaining(),  // input buffer size (input size + padding)
-            decompressed.size(),  // target output size
-            decompressed.size());  // output buffer size
-        if (ret < 0 || unsigned(ret) != decompressed.size()) {
+            decompressed_size,  // target output size
+            decompressed_size);  // output buffer size
+        if (ret < 0 || unsigned(ret) != decompressed_size) {
           return DropGraphite("Decompression failed with error code %d", ret);
         }
-        return this->Parse(decompressed.data(), decompressed.size(), true);
+        return this->Parse(decompressed.get(), decompressed_size, true);
       }
       default:
         return DropGraphite("Unknown compression scheme");
